import sys
import typing


def assign_action():
    ''' Set this pose Action as active Action on the active Object :file: addons/pose_library/operators.py\:196 <https://developer.blender.org/diffusion/BA/addons/pose_library/operators.py$196> _

    '''

    pass


def clear():
    ''' Delete all asset metadata and turn the selected asset data-blocks back into normal data-blocks

    '''

    pass


def list_refresh():
    ''' Trigger a reread of the assets

    '''

    pass


def mark():
    ''' Enable easier reuse of selected data-blocks through the Asset Browser, with the help of customizable metadata (like previews, descriptions and tags)

    '''

    pass


def open_containing_blend_file():
    ''' Open the blend file that contains the active asset :file: startup/bl_operators/assets.py\:101 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/assets.py$101> _

    '''

    pass


def tag_add():
    ''' Add a new keyword tag to the active asset :file: startup/bl_operators/assets.py\:41 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/assets.py$41> _

    '''

    pass


def tag_remove():
    ''' Remove an existing keyword tag from the active asset :file: startup/bl_operators/assets.py\:66 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/assets.py$66> _

    '''

    pass
